Ext.namespace("dSA", "dSA.functions");

dSA.functions.ReregisterDevices = function(dsid)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/dsm/restartRegistration',
        disableCaching: true,
        method: 'GET',
        params: { dsid : dsid },
        success: function(response, opts)
        {
            try
            {
                dSA.util.checkResponse(response);
                dSA.MessageBus.fireEvent('statusmessage',
                    dSA._("Device registration restarted"));
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not reregister devices") +
                    dSA.util.colon(error));
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not reregister devices") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
        }
    });
};

// callback(success, task_id)
dSA.functions.CheckTransmissionQuality = function(dsid, checksPerDevice,
                                                  callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/hardware/testDeviceTransmissionQuality',
        disableCaching: true,
        method: 'GET',
        params:
        {
            dsm : dsid,
            checksPerDevice: checksPerDevice
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (data.task === undefined)
                {
                    throw "received invalid task id";
                }

                if (callback !== undefined)
                {
                    callback(true, data.task);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not start transmission quality test") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not start transmission quality test") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });

};

// callback(taskObject)
dSA.functions.getTaskResultSummary = function(taskID, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/tasks/resultSummary',
        disableCaching: true,
        method: 'GET',
        params:
        {
            id : taskID
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (data.task === undefined)
                {
                    throw "received unexpected reply";
                }

                if (callback !== undefined)
                {
                    callback(true, data.task);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not retrieve task summary") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not retrieve task summary") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });

};

// callback(success, task_id)
dSA.functions.CheckDevicePresence = function(dsid, interval,
                                                  callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/hardware/testDevicePresence',
        disableCaching: true,
        method: 'GET',
        params:
        {
            dsm : dsid,
            interval : interval
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (data.task === undefined)
                {
                    throw "received invalid task id";
                }

                if (callback !== undefined)
                {
                    callback(true, data.task);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not start device presence test") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not start device presence test") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

// callback(success, present)
dSA.functions.CheckSingleDevicePresence = function(dsid, dsmdsid, timeout,
                                                   callback)
{
    return Ext.Ajax.request(
    {
        url: '/dsa/json/device/testDevicePresence',
        disableCaching: true,
        method: "GET",
        params:
        {
            dsid: dsid,
            dsm_dsid: dsmdsid,
            timeout: timeout
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data.present);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not start device presence test") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not start device presence test") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

// callback(success, errmsg)
dSA.functions.AbortTask = function(task_id, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/task/cancel',
        disableCaching: true,
        method: 'GET',
        params:
        {
            id : task_id
        },
        success: function(response, opts)
        {
            try
            {
                dSA.util.checkResponse(response);
                if (callback !== undefined)
                {
                    callback(true);
                }
            }
            catch (error)
            {
                if (callback !== undefined)
                {
                    callback(false, error);
                }
            }
        },
        failure: function(response, opts)
        {
            if (callback !== undefined)
            {
                callback(false, dSA.util.failureMessage(response));
            }
        }
    });
};

dSA.functions.GetTaskStatus = function(task_id, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/task/status',
        disableCaching: true,
        method: 'GET',
        params:
        {
            id : task_id
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                if (callback !== undefined)
                {
                    callback(false, error);
                }
            }
        },
        failure: function(response, opts)
        {
            if (callback !== undefined)
            {
                callback(false, dSA.util.failureMessage(response));
            }
        }
    });
};

// callback(success, taskdata)
dSA.functions.GetCurrentTask = function(callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/task/getCurrent',
        disableCaching: true,
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not get current task information") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }

        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not get current task information") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.BlinkLEDonDSM = function(dsid)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/dsm/blink',
        disableCaching: true,
        method: 'GET',
        params: { dsid : dsid },
        success: function(response, opts)
        {
            try
            {
                dSA.util.checkResponse(response);
                dSA.MessageBus.fireEvent('statusmessage',
                    dSA._("dSM LED is now blinking"));
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not blink LED on dSM") +
                    dSA.util.colon(error));
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not blink LED on dSM") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
        }
    });
};

dSA.functions.StartDeviceMonitor = function(callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/hardware/testDeviceMonitor',
        disableCaching: true,
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                dSA.MessageBus.fireEvent('statusmessage',
                    dSA._("Activated device monitor."));
                var data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data.task);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not activate device monitor") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not activate device monitor") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.GetDeviceMonitorStatus = function(id, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/hardware/testDeviceMonitorStatus',
        disableCaching: true,
        params: { id: id },
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not receive device information") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not receive device information") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.GetDevice = function(dsid, dsm_dsid, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/hardware/getDevice',
        disableCaching: true,
        params: { dsid: dsid, dsm: dsm_dsid },
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                var data;

                data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not receive device information") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};
